@@ -13,12 +13,16 @@
 from gi.repository import GLib, GdkPixbuf, Gio, Gst
 
 from random import choice
+from hashlib import md5
+from gettext import gettext as _
+from time import time
 
-from lollypop.tagreader import TagReader
-from lollypop.define import App, ArtSize, ArtBehaviour
-from lollypop.objects import Album
+from lollypop.tagreader import Discoverer
+from lollypop.define import App, ArtSize, ArtBehaviour, StorageType
+from lollypop.define import CACHE_PATH, TMP_PATH, STORE_PATH
+from lollypop.objects_album import Album
 from lollypop.logger import Logger
-from lollypop.utils import escape, is_readonly
+from lollypop.utils import is_readonly, emit_signal
 from lollypop.helper_task import TaskHelper
 
 
@@ -51,7 +55,7 @@ class AlbumArt:
         filename = ""
         try:
             filename = self.get_album_cache_name(album)
-            cache_path_jpg = "%s/%s_%s_%s.jpg" % (self._CACHE_PATH,
+            cache_path_jpg = "%s/%s_%s_%s.jpg" % (CACHE_PATH,
                                                   filename,
                                                   width,
                                                   height)
@@ -80,10 +84,10 @@ class AlbumArt:
         try:
             filename = self.get_album_cache_name(album) + ".jpg"
             self.__update_album_uri(album)
-            if album.mtime == 0:
-                store_path = self._WEB_PATH + "/" + filename
+            if album.storage_type & StorageType.EPHEMERAL:
+                store_path = TMP_PATH + "/" + filename
             else:
-                store_path = self._STORE_PATH + "/" + filename
+                store_path = STORE_PATH + "/" + filename
             uris = [
                 # Used when album.uri is readonly or for Web
                 GLib.filename_to_uri(store_path),
@@ -174,7 +178,7 @@ class AlbumArt:
         else:
             w = width
             h = height
-        cache_path_jpg = "%s/%s_%s_%s.jpg" % (self._CACHE_PATH, filename, w, h)
+        cache_path_jpg = "%s/%s_%s_%s.jpg" % (CACHE_PATH, filename, w, h)
         pixbuf = None
         try:
             # Look in cache
@@ -240,8 +244,8 @@ class AlbumArt:
         try:
             album = Album(album_id)
             filename = self.get_album_cache_name(album) + ".jpg"
-            web_path = self._WEB_PATH + "/" + filename
-            store_path = self._STORE_PATH + "/" + filename
+            web_path = TMP_PATH + "/" + filename
+            store_path = STORE_PATH + "/" + filename
             web_file = Gio.File.new_for_path(web_path)
             store_file = Gio.File.new_for_path(store_path)
             web_file.copy(store_file, Gio.FileCopyFlags.OVERWRITE,
@@ -256,7 +260,7 @@ class AlbumArt:
             @param album as Album
         """
         try:
-            if album.mtime == 0:
+            if album.storage_type & StorageType.EPHEMERAL:
                 self.__save_web_album_artwork(data, album)
             elif album.uri == "" or is_readonly(album.uri):
                 self.__save_ro_album_artwork(data, album)
@@ -270,7 +274,7 @@ class AlbumArt:
             Announce album cover update
             @param album_id as int
         """
-        self.emit("album-artwork-changed", album_id)
+        emit_signal(self, "album-artwork-changed", album_id)
 
     def remove_album_artwork(self, album):
         """
@@ -287,7 +291,7 @@ class AlbumArt:
                     f.delete(None)
                 except Exception as e:
                     Logger.error("AlbumArt::remove_album_artwork(): %s" % e)
-        self.__write_image_to_tags("", album.id)
+        self.__write_image_to_tags("", album)
 
     def clean_album_cache(self, album, width=-1, height=-1):
         """
@@ -300,10 +304,10 @@ class AlbumArt:
             from pathlib import Path
             name = self.get_album_cache_name(album)
             if width == -1 or height == -1:
-                for p in Path(self._CACHE_PATH).glob("%s*.jpg" % name):
+                for p in Path(CACHE_PATH).glob("%s*.jpg" % name):
                     p.unlink()
             else:
-                filename = "%s/%s_%s_%s.jpg" % (self._CACHE_PATH,
+                filename = "%s/%s_%s_%s.jpg" % (CACHE_PATH,
                                                 name,
                                                 width,
                                                 height)
@@ -322,8 +326,8 @@ class AlbumArt:
         if uri.startswith("web:"):
             return
         try:
-            tag_reader = TagReader()
-            info = tag_reader.get_info(uri)
+            discoverer = Discoverer()
+            info = discoverer.get_info(uri)
             exist = False
             if info is not None:
                 (exist, sample) = info.get_tags().get_sample_index("image", 0)
@@ -346,10 +350,10 @@ class AlbumArt:
             Get a uniq string for album
             @param album as Album
         """
-        name = "%s_%s_%s" % (" ".join(album.artists)[:100],
-                             album.name[:100],
+        name = "%s_%s_%s" % (" ".join(album.artists),
+                             album.name,
                              album.year)
-        return "@ALBUM@" + escape(name)
+        return md5(name.encode("utf-8")).hexdigest()
 
 #######################
 # PRIVATE             #
@@ -377,8 +381,14 @@ class AlbumArt:
             @param album as Album
         """
         filename = self.get_album_cache_name(album) + ".jpg"
-        store_path = self._WEB_PATH + "/" + filename
-        self._save_pixbuf_from_data(store_path, data)
+        store_path = TMP_PATH + "/" + filename
+        if data is None:
+            f = Gio.File.new_for_path(store_path)
+            fstream = f.replace(None, False,
+                                Gio.FileCreateFlags.REPLACE_DESTINATION, None)
+            fstream.close()
+        else:
+            self.save_pixbuf_from_data(store_path, data)
         self.clean_album_cache(album)
         GLib.idle_add(self.album_artwork_update, album.id)
 
@@ -389,8 +399,14 @@ class AlbumArt:
             @param album as Album
         """
         filename = self.get_album_cache_name(album) + ".jpg"
-        store_path = self._STORE_PATH + "/" + filename
-        self._save_pixbuf_from_data(store_path, data)
+        store_path = STORE_PATH + "/" + filename
+        if data is None:
+            f = Gio.File.new_for_path(store_path)
+            fstream = f.replace(None, False,
+                                Gio.FileCreateFlags.REPLACE_DESTINATION, None)
+            fstream.close()
+        else:
+            self.save_pixbuf_from_data(store_path, data)
         self.clean_album_cache(album)
         GLib.idle_add(self.album_artwork_update, album.id)
 
@@ -401,8 +417,9 @@ class AlbumArt:
             @param album as Album
         """
         filename = self.get_album_cache_name(album) + ".jpg"
-        store_path = self._STORE_PATH + "/" + filename
+        store_path = STORE_PATH + "/" + filename
         save_to_tags = App().settings.get_value("save-to-tags")
+        # Multiple albums at same path
         uri_count = App().albums.get_uri_count(album.uri)
         art_uri = album.uri + "/" + self.__favorite
 
@@ -421,7 +438,13 @@ class AlbumArt:
         if uri_count > 1:
             art_uri = album.uri + "/" + filename
 
-        self._save_pixbuf_from_data(store_path, data)
+        if data is None:
+            f = Gio.File.new_for_path(store_path)
+            fstream = f.replace(None, False,
+                                Gio.FileCreateFlags.REPLACE_DESTINATION, None)
+            fstream.close()
+        else:
+            self.save_pixbuf_from_data(store_path, data)
         dst = Gio.File.new_for_uri(art_uri)
         src = Gio.File.new_for_path(store_path)
         src.move(dst, Gio.FileCopyFlags.OVERWRITE, None, None)
@@ -438,36 +461,36 @@ class AlbumArt:
         bytes = GLib.Bytes(data)
         stream = Gio.MemoryInputStream.new_from_bytes(bytes)
         pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
-                                                           ArtSize.MONSTER,
-                                                           ArtSize.MONSTER,
+                                                           ArtSize.MPRIS,
+                                                           ArtSize.MPRIS,
                                                            True,
                                                            None)
         stream.close()
-        pixbuf.savev("%s/lollypop_cover_tags.jpg" % self._CACHE_PATH,
+        pixbuf.savev("%s/lollypop_cover_tags.jpg" % CACHE_PATH,
                      "jpeg", ["quality"], [str(App().settings.get_value(
                                            "cover-quality").get_int32())])
         self.__write_image_to_tags("%s/lollypop_cover_tags.jpg" %
-                                   self._CACHE_PATH, album.id)
+                                   CACHE_PATH, album)
 
-    def __write_image_to_tags(self, path, album_id):
+    def __write_image_to_tags(self, path, album):
         """
             Save album at path to album tags
             @param path as str
-            @param album_id as int
+            @param album as Album
         """
-        if self.kid3_available:
-            files = []
-            for uri in App().albums.get_track_uris(album_id):
-                try:
-                    files.append(GLib.filename_from_uri(uri)[0])
-                except:
-                    pass
-            cover = "%s/lollypop_cover_tags.jpg" % self._CACHE_PATH
-            if GLib.find_program_in_path("flatpak-spawn") is not None:
-                argv = ["flatpak-spawn", "--host", "kid3-cli",
-                        "-c", "set picture:'%s' ''" % cover]
-            else:
-                argv = ["kid3-cli", "-c", "set picture:'%s' ''" % cover]
+        files = []
+        for track in album.tracks:
+            App().tracks.set_mtime(track.id, int(time()) + 10)
+            filename = GLib.filename_from_uri(track.uri)[0]
+            if filename is not None:
+                files.append(filename)
+
+        worked = False
+        cover = "%s/lollypop_cover_tags.jpg" % CACHE_PATH
+        arguments = [["kid3-cli", "-c", "set picture:'%s' ''" % cover],
+                     ["flatpak-spawn", "--host", "kid3-cli",
+                      "-c", "set picture:'%s' ''" % cover]]
+        for argv in arguments:
             argv += files
             try:
                 (pid, stdin, stdout, stderr) = GLib.spawn_async(
@@ -477,9 +500,13 @@ class AlbumArt:
                     standard_output=False,
                     standard_error=False
                 )
+                worked = True
+                break
             except Exception as e:
-                Logger.error("AlbumArt::__on_kid3_result(): %s" % e)
-            self.clean_album_cache(Album(album_id))
-            # FIXME Should be better to send all covers at once and listen
-            # to as signal but it works like this
-            GLib.timeout_add(2000, self.album_artwork_update, album_id)
+                Logger.error("AlbumArt::__write_image_to_tags(): %s" % e)
+        if worked:
+            self.clean_album_cache(album)
+            GLib.timeout_add(2000, self.album_artwork_update, album.id)
+        else:
+            App().notify.send("Lollypop",
+                              _("You need to install kid3-cli"))
