@@ -26,7 +26,7 @@ import json
 from multiprocessing import cpu_count
 
 from lollypop.inotify import Inotify
-from lollypop.define import App, ScanType, Type, StorageType
+from lollypop.define import App, ScanType, Type, StorageType, ScanUpdate
 from lollypop.sqlcursor import SqlCursor
 from lollypop.tagreader import TagReader, Discoverer
 from lollypop.logger import Logger
@@ -50,9 +50,9 @@ class CollectionScanner(GObject.GObject, TagReader):
     """
     __gsignals__ = {
         "scan-finished": (GObject.SignalFlags.RUN_FIRST, None, (bool,)),
-        "artist-updated": (GObject.SignalFlags.RUN_FIRST, None, (int, bool)),
-        "genre-updated": (GObject.SignalFlags.RUN_FIRST, None, (int, bool)),
-        "album-updated": (GObject.SignalFlags.RUN_FIRST, None, (int, bool))
+        "artist-updated": (GObject.SignalFlags.RUN_FIRST, None, (int, int)),
+        "genre-updated": (GObject.SignalFlags.RUN_FIRST, None, (int, int)),
+        "album-updated": (GObject.SignalFlags.RUN_FIRST, None, (int, int))
     }
 
     _WEB_COLLECTION = GLib.get_user_data_dir() + "/lollypop/web_collection"
@@ -204,9 +204,10 @@ class CollectionScanner(GObject.GObject, TagReader):
                                                  album_rate, album_synced,
                                                  album_mtime, storage_type)
         if genres is None:
+            added_genre_ids = []
             genre_ids = [Type.WEB]
         else:
-            genre_ids = self.add_genres(genres)
+            (added_genre_ids, genre_ids) = self.add_genres(genres)
 
         # Add track to db
         Logger.debug("CollectionScanner::save_track(): Add track")
@@ -230,11 +231,15 @@ class CollectionScanner(GObject.GObject, TagReader):
             for artist_id in added_album_artist_ids:
                 if artist_id in self.__new_non_album_artists:
                     self.__new_non_album_artists.remove(artist_id)
-                emit_signal(self, "artist-updated", artist_id, True)
-            for genre_id in genre_ids:
-                emit_signal(self, "genre-updated", genre_id, True)
+                emit_signal(self, "artist-updated", artist_id,
+                            ScanUpdate.ADDED)
+            for genre_id in added_genre_ids:
+                emit_signal(self, "genre-updated", genre_id, ScanUpdate.ADDED)
             if album_added:
-                emit_signal(self, "album-updated", album_id, True)
+                emit_signal(self, "album-updated", album_id, ScanUpdate.ADDED)
+            else:
+                emit_signal(self, "album-updated", album_id,
+                            ScanUpdate.MODIFIED)
         return (track_id, album_id)
 
     def update_track(self, track_id, artist_ids, genre_ids):
@@ -251,12 +256,11 @@ class CollectionScanner(GObject.GObject, TagReader):
         for genre_id in genre_ids:
             App().tracks.add_genre(track_id, genre_id)
 
-    def del_from_db(self, uri, backup, notify=True):
+    def del_from_db(self, uri, backup):
         """
             Delete track from db
             @param uri as str
             @param backup as bool
-            @param notify as bool => send signal about cleanup
             @return (popularity, ltime, mtime,
                      loved album, album_popularity)
         """
@@ -290,12 +294,18 @@ class CollectionScanner(GObject.GObject, TagReader):
             App().genres.clean()
             App().artists.clean()
             SqlCursor.commit(App().db)
-            if notify and App().albums.get_name(album_id) is None:
-                emit_signal(self, "album-updated", album_id, False)
+            if not App().albums.get_name(album_id):
+                emit_signal(self, "album-updated", album_id,
+                            ScanUpdate.REMOVED)
                 for artist_id in album_artist_ids + artist_ids:
-                    emit_signal(self, "artist-updated", artist_id, False)
+                    emit_signal(self, "artist-updated", artist_id,
+                                ScanUpdate.REMOVED)
                 for genre_id in genre_ids:
-                    emit_signal(self, "genre-updated", genre_id, False)
+                    emit_signal(self, "genre-updated", genre_id,
+                                ScanUpdate.REMOVED)
+            else:
+                emit_signal(self, "album-updated", album_id,
+                            ScanUpdate.MODIFIED)
             return (track_pop, track_rate, track_ltime, album_mtime,
                     track_loved, album_loved, album_pop, album_rate)
         except Exception as e:
@@ -579,7 +589,8 @@ class CollectionScanner(GObject.GObject, TagReader):
         for artist_id in self.__new_non_album_artists:
             album_ids = App().albums.get_ids([artist_id], [])
             if album_ids:
-                emit_signal(self, "artist-updated", artist_id, True)
+                emit_signal(self, "artist-updated",
+                            artist_id, ScanUpdate.ADDED)
         SqlCursor.remove(App().db)
 
     def __remove_old_tracks(self, uris, scan_type):
