@@ -53,15 +53,14 @@ class ViewsContainer:
                 self._stack.set_transition_type(
                     Gtk.StackTransitionType.CROSSFADE)
                 App().enable_special_shortcuts(True)
+                if App().lookup_action("reload").get_state():
+                    self.reload_view()
             if self.can_go_back:
                 emit_signal(self, "can-go-back-changed", True)
 
-        from lollypop.view import View
-        view = View(ViewType.SCROLLED)
+        from lollypop.view_menu import MenuView
+        view = MenuView(widget)
         view.show()
-        view.add_widget(widget)
-        widget.get_style_context().add_class("adaptive-menu")
-        widget.set_vexpand(True)
         widget.connect("hidden", on_hidden, view)
         self._stack.add(view)
         self._stack.set_transition_type(Gtk.StackTransitionType.SLIDE_DOWN)
@@ -82,7 +81,7 @@ class ViewsContainer:
             if item_ids[0] in [Type.POPULARS,
                                Type.LOVED,
                                Type.RECENTS,
-                               Type.NEVER,
+                               Type.LITTLE,
                                Type.RANDOMS,
                                Type.WEB]:
                 view = self._get_view_albums(item_ids, [])
@@ -204,8 +203,8 @@ class ViewsContainer:
             items = App().albums.get_loved_albums()
         elif genre_ids and genre_ids[0] == Type.RECENTS:
             items = App().albums.get_recents()
-        elif genre_ids and genre_ids[0] == Type.NEVER:
-            items = App().albums.get_never_listened_to()
+        elif genre_ids and genre_ids[0] == Type.LITTLE:
+            items = App().albums.get_little_played()
         elif genre_ids and genre_ids[0] == Type.RANDOMS:
             items = App().albums.get_randoms()
         elif genre_ids and genre_ids[0] == Type.COMPILATIONS:
@@ -281,8 +280,12 @@ class ViewsContainer:
             @param genre_ids as [int]
             @param artist_ids as [int]
         """
-        from lollypop.view_artist import ArtistView
-        view = ArtistView(genre_ids, artist_ids)
+        if App().settings.get_value("show-artist-tracks"):
+            from lollypop.view_artist_list import ArtistViewList
+            view = ArtistViewList(genre_ids, artist_ids)
+        else:
+            from lollypop.view_artist_box import ArtistViewBox
+            view = ArtistViewBox(genre_ids, artist_ids)
         view.populate()
         view.show()
         return view
@@ -313,7 +316,8 @@ class ViewsContainer:
             @param album as Album
         """
         from lollypop.view_album import AlbumView
-        view_type = ViewType.TWO_COLUMNS | ViewType.SCROLLED
+        view_type = ViewType.TWO_COLUMNS | ViewType.SCROLLED |\
+            ViewType.OVERLAY
         view = AlbumView(album, view_type)
         view.populate()
         return view
