@@ -104,12 +104,14 @@ class Playlists(GObject.GObject):
         """
         if name == _("Loved tracks"):
             return Type.LOVED
+        lastrowid = 0
         with SqlCursor(self, True) as sql:
             result = sql.execute("INSERT INTO playlists (name, mtime)\
                                   VALUES (?, ?)",
                                  (name, 0))
-            emit_signal(self, "playlists-changed", result.lastrowid)
-            return result.lastrowid
+            lastrowid = result.lastrowid
+        emit_signal(self, "playlists-changed", lastrowid)
+        return lastrowid
 
     def exists(self, playlist_id):
         """
@@ -139,13 +141,15 @@ class Playlists(GObject.GObject):
                         WHERE rowid=?",
                         (name, playlist_id))
         emit_signal(self, "playlists-changed", playlist_id)
-        App().art.remove_artwork_from_cache(name, "ROUNDED")
+        App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
 
     def remove(self, playlist_id):
         """
             Remove playlist
             @param playlist_id as int
         """
+        name = self.get_name(playlist_id)
+        App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
         with SqlCursor(self, True) as sql:
             sql.execute("DELETE FROM playlists\
                         WHERE rowid=?",
@@ -153,7 +157,7 @@ class Playlists(GObject.GObject):
             sql.execute("DELETE FROM tracks\
                         WHERE playlist_id=?",
                         (playlist_id,))
-            emit_signal(self, "playlists-changed", playlist_id)
+        emit_signal(self, "playlists-changed", playlist_id)
 
     def clear(self, playlist_id):
         """
@@ -287,8 +291,8 @@ class Playlists(GObject.GObject):
                 track_ids.append(track)
         elif playlist_id == Type.RECENTS:
             track_ids = App().tracks.get_recently_listened_to()
-        elif playlist_id == Type.NEVER:
-            track_ids = App().tracks.get_never_listened_to()
+        elif playlist_id == Type.LITTLE:
+            track_ids = App().tracks.get_little_played()
         elif playlist_id == Type.RANDOMS:
             track_ids = App().tracks.get_randoms()
         elif playlist_id == Type.ALL:
@@ -592,7 +596,7 @@ class Playlists(GObject.GObject):
         try:
             name = self.get_name(playlist_id)
             # Clear cache
-            App().art.remove_artwork_from_cache(name, "ROUNDED")
+            App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
             uri = self.get_sync_uri(playlist_id)
             if uri is None:
                 return
