@@ -10,56 +10,63 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib
+from gi.repository import Gtk, GLib, GObject
 
-from lollypop.define import App, ViewType, MARGIN
+from lollypop.define import App, ViewType, MARGIN, ScanUpdate
 from lollypop.view_tracks import TracksView
 from lollypop.widgets_banner_album import AlbumBannerWidget
 from lollypop.controller_view import ViewController, ViewControllerType
-from lollypop.view import LazyLoadingView
+from lollypop.view_lazyloading import LazyLoadingView
 from lollypop.helper_filtering import FilteringHelper
+from lollypop.helper_signals import SignalsHelper, signals_map
 from lollypop.logger import Logger
+from lollypop.objects_album import Album
 
 
-class AlbumView(FilteringHelper, LazyLoadingView, ViewController):
+class AlbumView(FilteringHelper, LazyLoadingView,
+                ViewController, SignalsHelper):
     """
         Show artist albums and tracks
     """
 
+    __gsignals__ = {
+        "populated": (GObject.SignalFlags.RUN_FIRST, None, ()),
+    }
+
+    @signals_map
     def __init__(self, album, view_type):
         """
             Init ArtistView
             @param album as Album
             @param view_type as ViewType
         """
-        LazyLoadingView.__init__(self, view_type |
-                                 ViewType.OVERLAY |
-                                 ViewType.ALBUM)
+        LazyLoadingView.__init__(self, view_type | ViewType.ALBUM)
         ViewController.__init__(self, ViewControllerType.ALBUM)
         FilteringHelper.__init__(self)
-        self._album = album
-        self.__tracks_view = TracksView(album, App().window, None,
-                                        ViewType.TWO_COLUMNS | ViewType.ALBUM)
-        self.__tracks_view.show()
-        self.__tracks_view.connect("populated", self.__on_tracks_populated)
-        self.__tracks_view.set_margin_start(MARGIN)
-        self.__tracks_view.set_margin_end(MARGIN)
+        self.__album = album
         self.__others_boxes = []
         self.__grid = Gtk.Grid()
         self.__grid.show()
         self.__grid.set_row_spacing(10)
         self.__grid.set_orientation(Gtk.Orientation.VERTICAL)
-        self.__grid.add(self.__tracks_view)
-        self.__banner = AlbumBannerWidget(self._album,
-                                          self._view_type | ViewType.ALBUM)
-        self.__banner.show()
+        self.__banner = AlbumBannerWidget(self.__album, self._view_type)
         self.add_widget(self.__grid, self.__banner)
+        return [
+            (App().scanner, "scan-finished", "_on_scan_finished"),
+            (App().scanner, "album-updated", "_on_album_updated")
+        ]
 
     def populate(self):
         """
             Populate the view with album
         """
+        self.__tracks_view = TracksView(self.__album, ViewType.ALBUM)
+        self.__tracks_view.show()
+        self.__tracks_view.connect("populated", self.__on_tracks_populated)
+        self.__tracks_view.set_margin_start(MARGIN)
+        self.__tracks_view.set_margin_end(MARGIN)
         self.__tracks_view.populate()
+        self.__grid.add(self.__tracks_view)
 
     def activate_child(self):
         """
@@ -87,7 +94,7 @@ class AlbumView(FilteringHelper, LazyLoadingView, ViewController):
             Get default args for __class__
             @return {}
         """
-        return {"album": self._album, "view_type": self.view_type}
+        return {"album": self.__album, "view_type": self.view_type}
 
     @property
     def filtered(self):
@@ -117,9 +124,41 @@ class AlbumView(FilteringHelper, LazyLoadingView, ViewController):
         """
         return self.__tracks_view
 
+    @property
+    def is_populated(self):
+        """
+            True if populated
+            @return bool
+        """
+        return True
+
 #######################
 # PROTECTED           #
 #######################
+    def _on_scan_finished(self, scanner, modifications):
+        """
+            Reload album if needed
+            @param scanner as CollectionScanner
+            @param modifications as bool
+        """
+        if not self.get_sensitive():
+            App().window.container.reload_view()
+
+    def _on_album_updated(self, scanner, album_id, scan_update):
+        """
+            Handles changes in collection
+            @param scanner as CollectionScanner
+            @param album_id as int
+            @param scan_update as ScanUpdate
+        """
+        if album_id != self.__album.id:
+            return
+        if scan_update == ScanUpdate.REMOVED:
+            App().window.container.go_back()
+        elif scan_update == ScanUpdate.MODIFIED:
+            self.set_sensitive(False)
+            self.__album = Album(self.__album.id)
+
     def _on_current_changed(self, player):
         """
             Update children state
@@ -135,18 +174,6 @@ class AlbumView(FilteringHelper, LazyLoadingView, ViewController):
         """
         self.__tracks_view.update_duration(track_id)
 
-    def _on_album_updated(self, scanner, album_id, added):
-        """
-            Handles changes in collection
-            @param scanner as CollectionScanner
-            @param album_id as int
-            @param added as bool
-        """
-        # Check we are not destroyed
-        if album_id == self._album.id and not added:
-            App().window.go_back()
-            return
-
 #######################
 # PRIVATE             #
 #######################
@@ -156,16 +183,19 @@ class AlbumView(FilteringHelper, LazyLoadingView, ViewController):
             @param view as TracksView
         """
         if self.__tracks_view.is_populated:
-            from lollypop.view_albums_box import AlbumsArtistBoxView
-            for artist_id in self._album.artist_ids:
-                others_box = AlbumsArtistBoxView(self._album, artist_id,
-                                                 ViewType.SMALL |
-                                                 ViewType.ALBUM |
-                                                 ViewType.SCROLLED)
-                others_box.set_margin_start(MARGIN)
-                others_box.set_margin_end(MARGIN)
-                others_box.populate()
-                self.__grid.add(others_box)
-                self.__others_boxes.append(others_box)
+            self.emit("populated")
+            self.__banner.show()
+            if self._view_type & ViewType.OVERLAY:
+                from lollypop.view_albums_box import AlbumsArtistBoxView
+                for artist_id in self.__album.artist_ids:
+                    others_box = AlbumsArtistBoxView(self.__album, artist_id,
+                                                     ViewType.SMALL |
+                                                     ViewType.ALBUM |
+                                                     ViewType.SCROLLED)
+                    others_box.set_margin_start(MARGIN)
+                    others_box.set_margin_end(MARGIN)
+                    others_box.populate()
+                    self.__grid.add(others_box)
+                    self.__others_boxes.append(others_box)
         else:
             self.__tracks_view.populate()
