@@ -70,7 +70,7 @@ class CurrentAlbumsView(View, SignalsHelper):
             Get default args for __class__
             @return {}
         """
-        return {"view_type": self.view_type}
+        return {"view_type": self.view_type & ~ViewType.SCROLLED}
 
 #######################
 # PROTECTED           #
@@ -107,7 +107,7 @@ class CurrentAlbumsView(View, SignalsHelper):
         self.__view.clear()
         self.__banner.clear_button.set_sensitive(True)
         self.__banner.jump_button.set_sensitive(True)
-        self.__banner.save_button.set_sensitive(True)
+        self.__banner.menu_button.set_sensitive(True)
         self.populate()
 
 #######################
@@ -122,4 +122,3 @@ class CurrentAlbumsView(View, SignalsHelper):
         for child in self.__view.children:
             albums.append(child.album)
         App().player.set_albums(albums)
-        App().player.update_next_prev()
